@@ -1,4 +1,4 @@
-# $Id: Directory.pm 40424 2013-10-14 12:41:18Z anton $
+# $Id: Directory.pm 40891 2014-01-27 10:42:11Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -72,12 +72,15 @@ sub accountTemporaryDisabled {
 	return $self->ldapEntry->get_value('accountTemporaryDisabled');
 }
 
+
 sub stuff {
 	my $entry = $self->ldapEntry;
 
 	my %userinfo;
 	foreach my $attr (
 		qw(
+        accountBlocked
+        accountStatus
         accountSuspended
         accountTemporaryDisabled
         cn
@@ -86,13 +89,17 @@ sub stuff {
         givenName
         mail
         mailhost
-        passwordExpirationStatus
+        passwordExpirationStage
+        passwordExpirationStageTime
+        passwordExpirationFinalDay
+        passwordStatus
         privateEmail
         rcryptPassword
         sn
         tiasPrivateEmail
         uid            
-        uvt-auth
+        unpaidFees
+
          )) {
 		$userinfo{$attr} = $entry->get_value($attr);
 	}
@@ -105,10 +112,10 @@ sub stuff {
 
     $userinfo{ou} = [$entry->get_value('ou;lang-nl')];
 	$userinfo{'uvt-lau'} = [$entry->get_value('uvt-lau')];
+	$userinfo{'uvt-auth'} = [$entry->get_value('uvt-auth')];
+
 	$userinfo{entry} = $entry;
 
-    # NB er zijn 'niet studenten' met een studentenaccount op de studentenserver!
-    # kijk dus NIET naar de organizationalStatus, want dan vallen deze buiten de boot.
     my $uid = $userinfo{uid};
     $userinfo{studentaccount} = $uid =~ /^(s\d{6}|u\d{7})$/i;
 
@@ -122,7 +129,7 @@ sub stuff {
 
 package UvT::PwdModifier::Directory;
 use Net::LDAP::Control::Paged;
-use Net::LDAP::Constant qw( LDAP_CONTROL_PAGED ); 
+use Net::LDAP::Constant qw(LDAP_CONTROL_PAGED); 
 
 use Data::Dumper;
 use Carp qw(cluck carp confess);
@@ -179,7 +186,7 @@ sub ldap_connection {
 
 		$self->ldap($ldap);
 	}
-	warn "About to bind" if $self->debug;
+#	warn "About to bind" if $self->debug;
 	my $bindAccountFilter = $self->bindAccountFilter;
 	if ($bindAccountFilter) {
 		my $base = $cf->value('ldapbase');
@@ -263,6 +270,7 @@ sub verify_password {
 		my $converted = MIME::Base64::encode_base64($digest);
 		# vergeet niet de \n eraf te slopen!
 		chomp $converted;
+		warn "converted: $converted";
 		eval { $ldap->bind($dn, password => $converted) };
 		$err = $@;
 	}
@@ -361,7 +369,7 @@ sub searchLdap {
 
 sub getEntriesByUID {
 	my $uid = shift;
-	warn "getLdapAccoutByUid: $uid" if $self->debug;
+	warn "getEntriesByUid: $uid" if $self->debug;
 	my $ldap = $self->ldap_connection();
 	my $cf = $self->cf;
 	my $base = $cf->value('ldapbase');
@@ -388,40 +396,20 @@ sub getEntryByUID {
 	return ($self->getEntriesByUID($uid), $ldap);
 }
 
-sub setPasswordExpirationStatus {
-	my ($uid, $status) = @_;
-	my $attrib = 'passwordExpirationStatus';
-	my ($entry, $ldap) = $self->getEntryByUID($uid);
-	warn "about to replace $attrib: $status for $uid" if $self->debug;
-	if ($status) {
-		$entry->replace($attrib , $status);
-	} else {
-		$entry->delete($attrib);
-	}
-	my $msg = $entry->update($ldap);
-
-	if ($msg->code) {
-		warn("setPasswordExpirationStatus failed:", $msg->error());
-	} else {
-		warn "setPasswordExpirationStatus succeeded";
-	}
-}
-
 sub getRcryptPassword {
 	my ($uid) = @_;
 	my ($entry, $ldap) = $self->getEntryByUID($uid);
 	return $entry->get_value('rcryptPassword');
 }
 
-sub changeAccountTemporaryDisabledState {
-	my ($uid, $admin, $on) = @_;
-	my $attrib = 'accountTemporaryDisabled';
+sub toggleAccountState {
+	my ($attrib, $uid, $on, $label) = @_;
 	my ($entry, $ldap) = $self->getEntryByUID($uid);
 
 	if ($on) {
 		my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
 		$year += 1900; $mday +=1 ;
-		my $content = sprintf("Disabled at: $year-%02d-%02d %02d:%02d by: $admin", $mon, $mday, $hour,$min);
+		my $content = sprintf("$label at: $year-%02d-%02d %02d:%02d", $mon, $mday, $hour,$min);
 		$entry->replace($attrib, $content);
 	} else {
 		$entry->delete($attrib);
@@ -429,10 +417,26 @@ sub changeAccountTemporaryDisabledState {
 
 	my $msg = $entry->update($ldap);
 	if ($msg->code) {
-		warn("accountTemporaryDisabled failed:", $msg->error());
+		warn("toggleAccountState failed:", $msg->error());
 	} else {
-		warn "accountTemporaryDisabled succeeded" if $self->debug;
+		warn "toggleAccountState succeeded" if $self->debug;
 	}
 }
 
+sub replaceAttribute {
+	my ($uid, $attrib, $value) = @_;
+	my ($entry, $ldap) = $self->getEntryByUID($uid);
+	if (defined($value)) {
+		$entry->replace($attrib, $value);
+	} else {
+		$entry->delete($attrib);
+	}
+	my $msg = $entry->update($ldap);
+	
+	if ($msg->code) {
+		die("Error setting attrib: $attrib", $msg->error());
+	}
+}
+
+
 0;
